跳到主要内容

FipsStatus

搜索

枚举 FipsStatus 

pub enum FipsStatus {
    Unvalidated,
    Pending,
#[non_exhaustive]
Certified { certificate: &'static str, }, }
展开描述

某算法或实现的 FIPS 验证状态。

变体



Unvalidated

未经过 FIPS 测试,或为未批准的算法。



Pending

正在排队等待 FIPS 验证。



#[non_exhaustive]
Certified

已通过 FIPS 认证,并附带具名证书。

字段

此变体被标记为非穷尽(non-exhaustive)
非穷尽枚举变体在未来可能会增加更多字段。因此,非穷尽枚举变体无法在外部 crate 中构造,也不能在匹配中穷尽列举。
certificate: &'static str

引用该 FIPS 证书的名称、编号或 URL。

trait 实现

Source

impl Clone for FipsStatus

Source

fn clone(&self) -> FipsStatus

返回该值的一个副本。更多信息
1.0.0 · Source

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
Source

impl Debug for FipsStatus

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。更多信息
Source

impl Ord for FipsStatus

Source

fn cmp(&self, other: &FipsStatus) -> Ordering

该方法返回 selfother 之间的 Ordering更多信息
1.21.0 · Source

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values. 更多信息
1.21.0 · Source

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values. 更多信息
1.50.0 · Source

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval. 更多信息
Source

impl PartialEq for FipsStatus

Source

fn eq(&self, other: &FipsStatus) -> bool

测试 selfother 值是否相等,供 == 使用。
1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
Source

impl PartialOrd for FipsStatus

Source

fn partial_cmp(&self, other: &FipsStatus) -> Option<Ordering>

selfother 之间存在某种顺序,该方法返回相应的顺序。更多信息
1.0.0 · Source

fn lt(&self, other: &Rhs) -> bool

Tests less than (for self and other) and is used by the < operator. 更多信息
1.0.0 · Source

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator. 更多信息
1.0.0 · Source

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator. 更多信息
1.0.0 · Source

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator. 更多信息
Source

impl Copy for FipsStatus

Source

impl Eq for FipsStatus

Source

impl StructuralPartialEq for FipsStatus

自动 trait 实现

blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> CloneToUninit for T
where T: Clone,

Source

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::from(self).

即此转换的实际行为取决于 From<T> for U 的实现。

Source

impl<T> ToOwned for T
where T: Clone,

Source

type Owned = T

The resulting type after obtaining ownership.
Source

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
Source

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

The type returned in the event of a conversion error.
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

The type returned in the event of a conversion error.
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。